#!/bin/sh
# usr/opt/wrdapp/Cap_94.10/test/test.sh -- run culvert test data sets
#
# Usage: test.sh [start [stop]]
#        test.sh [start [stop] | tee test.out
#
#        where: start = starting test number
#                stop = ending test number (may be same as start)
#
# To use this script for another program in a different directory, globally
# change the program name (be sure to change both upper and lower case
# occurrences) and set the default value for the Stop variable as appropriate.
#
# History: 99/09/08 mcrouse
#
# Variable definitions
# --------------------
#
  TOPDIR=..
  DATA=$TOPDIR/data
  CHECK=$TOPDIR/test/check.sh
  CLEAN=$TOPDIR/test/clean.sh
  PROG=$TOPDIR/bin/Cap
  PROGNM=CAP
  DIVD=========================================
  end=7
#
#
  exec 2>&1                                # stderr shows up in .out file

  Start=${1:-1}                            # by default, start at 1
  Stop=${2:-$end}                          # by default, stop at $end
  if [ $Start -lt 1 ] ; then Start=1 ; fi
  if [ $Stop -lt 1 ] ; then Stop=$end ; fi
  if [ $Start -gt $end -o $Stop -gt $end ]
  then
    echo
    echo "Warning, invalid arguments--test range is 1 - $end for $PROGNM"
    echo "input arguments were $Start - $Stop"
    echo
    if [ $Stop -gt $end ] ; then Stop=$end ; fi
    if [ $Start -gt $end ]
    then
      echo "no $PROGNM tests will be performed"
    else
      echo "Tests $Start - $Stop will be performed"
    fi
    echo
  fi
#
# begin test runs
#
  Test=$Start

  if [ $Test -ge $Start -a $Test -le $Stop ]
  then
    echo
    echo $DIVD$DIVD
    echo "Begin processing $PROGNM test runs $Start to $Stop"
    echo
    date
  fi
#
# remove old output file
#
  $CLEAN

  while [ $Test -ge $Start -a $Test -le $Stop ]
  do
    echo
    echo
    echo $DIVD$DIVD
    echo "Test run number $Test"
    if [ $Test -eq 1 ]
    then
      Name=mercer
      echo 1 > go
      echo $Name.out >> go
      echo Mercer Creek culvert example >> go
      echo $DATA/$Name.dat >> go
      echo EX01 >> go
      echo $DATA/$Name.dat >> go
      echo AP01 >> go
    elif [ $Test -eq 2 ]
    then
      Name=pigeon
      echo 1 > go
      echo $Name.out >> go
      echo Pigeon House Creek culvert example >> go
      echo $DATA/$Name.dat >> go
      echo PCUL >> go
      echo $DATA/$Name.dat >> go
      echo PCRK >> go
    elif [ $Test -eq 3 ]
    then
      Name=riogran
      echo 1 > go
      echo riogran1.out >> go
      echo Rio Grande Conveyance Channel multi-culvert barrel 1 >> go
      echo $DATA/$Name.dat >> go
      echo BAR1 >> go
      echo $DATA/$Name.dat >> go
      echo APP1 >> go
      echo no >> go
      echo 1 >> go
      echo riogran2.out >> go
      echo Rio Grande Conveyance Channel multi-culvert barrel 2 >> go
      echo $DATA/$Name.dat >> go
      echo BAR2 >> go
      echo $DATA/$Name.dat >> go
      echo APP2 >> go
    elif [ $Test -eq 4 ]
    then
      Name=cultwri
      echo 2 > go
      echo $Name.out >> go
      echo TWRI creek culvert example >> go
      echo 12345678 >> go
      echo $DATA/$Name.dat >> go
      echo TWRI >> go
      echo $DATA/$Name.dat >> go
      echo ADOP >> go
    elif [ $Test -eq 5 ]
    then
      Name=twri8
      echo 1 > go
      echo $Name.out >> go
      echo Example 8 in TWRI concrete pipe culvert type 6 flow >> go
      echo $DATA/$Name.dat >> go
      echo EX01 >> go
      echo $DATA/$Name.dat >> go
      echo AP01 >> go
    elif [ $Test -eq 6 ]
    then
      Name=vellip
      echo 1 > go
      echo $Name.out >> go
      echo Vertical elliptical culvert section example w/o *CS records >> go
      echo $DATA/$Name.dat >> go
      echo EX01 >> go
      echo $DATA/$Name.dat >> go
      echo AP01 >> go
    elif [ $Test -eq 7 ]
    then
      Name=vellipcs
      echo 1 > go
      echo $Name.out >> go
      echo Vertical elliptical culvert section example using *CS records >> go
      echo $DATA/$Name.dat >> go
      echo EX01 >> go
      echo $DATA/$Name.dat >> go
      echo AP01 >> go
    fi
    echo yes >> go
    echo

    $PROG < go
    Test=`expr $Test + 1`
    rm -f go
  done
#
  if [ $Test -ge $Start -a $Test -le $Stop ]
  then
    echo
    echo
    echo $DIVD$DIVD
    echo "Completed $PROGNM test runs $Start to $Stop"
    echo
  fi

# check output against original output in ../data directory
  $CHECK mercer pigeon riogran cultwri twri8 vellip vellipcs
